@@ -1,9 +1,10 @@
-# -*- coding: utf-8 -*-
 """
 astLib - python astronomy modules
 
 (c) 2007-2012 Matt Hilton
 
+(c) 2013 Matt Hilton & Steven Boada
+
 U{http://astlib.sourceforge.net}
 
 See the README file for information on usage and installation.
@@ -11,5 +12,6 @@ See the LICENSE file for information on distribution.
 
 """
 
-__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS', 'astSED']
-__version__ = '0.6.1'
+__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS',
+    'astSED']
+__version__ = '0.7.0'
