@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 """module for simple .fits image tasks (rotation, clipping out sections, making .pngs etc.)
 
-(c) 2007-2011 Matt Hilton 
+(c) 2007-2013 Matt Hilton 
 
 U{http://astlib.sourceforge.net}
 
@@ -24,14 +23,14 @@ try:
     from scipy import ndimage
     from scipy import interpolate
 except:
-    print "WARNING: astImages: failed to import scipy.ndimage - some functions will not work."
+    print("WARNING: astImages: failed to import scipy.ndimage - some functions will not work.")
 import numpy
 try:
     import matplotlib
     from matplotlib import pylab
     matplotlib.interactive(False)
 except:
-    print "WARNING: astImages: failed to import matplotlib - some functions will not work."
+    print("WARNING: astImages: failed to import matplotlib - some functions will not work.")
 
 #---------------------------------------------------------------------------------------------------
 def clipImageSectionWCS(imageData, imageWCS, RADeg, decDeg, clipSizeDeg, returnWCS = True):
@@ -74,7 +73,7 @@ def clipImageSectionWCS(imageData, imageWCS, RADeg, decDeg, clipSizeDeg, returnW
         xHalfClipSizeDeg=clipSizeDeg[0]/2.0
         yHalfClipSizeDeg=clipSizeDeg[1]/2.0
     else:
-        raise Exception, "did not understand clipSizeDeg: should be float, or [widthDeg, heightDeg]"
+        raise Exception("did not understand clipSizeDeg: should be float, or [widthDeg, heightDeg]")
     
     xHalfSizePix=xHalfClipSizeDeg/xImScale
     yHalfSizePix=yHalfClipSizeDeg/yImScale    
@@ -117,7 +116,7 @@ def clipImageSectionWCS(imageData, imageWCS, RADeg, decDeg, clipSizeDeg, returnW
             
             if REPORT_ERRORS == True:
                 
-                print "WARNING: astImages.clipImageSectionWCS() : no CRPIX1, CRPIX2 keywords found - not updating clipped image WCS."
+                print("WARNING: astImages.clipImageSectionWCS() : no CRPIX1, CRPIX2 keywords found - not updating clipped image WCS.")
                 
                 clippedData=imageData[Y[0]:Y[1],X[0]:X[1]]
                 clippedWCS=imageWCS.copy()
@@ -154,7 +153,7 @@ def clipImageSectionPix(imageData, XCoord, YCoord, clipSizePix):
         xHalfClipSizePix=int(round(clipSizePix[0]/2.0))
         yHalfClipSizePix=int(round(clipSizePix[1]/2.0))
     else:
-        raise Exception, "did not understand clipSizePix: should be float, or [widthPix, heightPix]"
+        raise Exception("did not understand clipSizePix: should be float, or [widthPix, heightPix]")
        
     cTopLeft=[XCoord+xHalfClipSizePix, YCoord+yHalfClipSizePix]
     cBottomRight=[XCoord-xHalfClipSizePix, YCoord-yHalfClipSizePix]
@@ -220,7 +219,7 @@ def clipRotatedImageSectionWCS(imageData, imageWCS, RADeg, decDeg, clipSizeDeg,
         xHalfClipSizeDeg=clipSizeDeg[0]/2.0
         yHalfClipSizeDeg=clipSizeDeg[1]/2.0
     else:
-        raise Exception, "did not understand clipSizeDeg: should be float, or [widthDeg, heightDeg]"
+        raise Exception("did not understand clipSizeDeg: should be float, or [widthDeg, heightDeg]")
     
     diagonalHalfSizeDeg=math.sqrt((xHalfClipSizeDeg*xHalfClipSizeDeg) \
         +(yHalfClipSizeDeg*yHalfClipSizeDeg))
@@ -311,7 +310,7 @@ def clipRotatedImageSectionWCS(imageData, imageWCS, RADeg, decDeg, clipSizeDeg,
             except KeyError:
                 
                 if REPORT_ERRORS == True:
-                    print "WARNING: astImages.clipRotatedImageSectionWCS() : no CDi_j keywords found - not rotating WCS."
+                    print("WARNING: astImages.clipRotatedImageSectionWCS() : no CDi_j keywords found - not rotating WCS.")
                     
                 imageRotated=diagonalClip
                 rotatedWCS=diagonalWCS
@@ -326,8 +325,8 @@ def clipRotatedImageSectionWCS(imageData, imageWCS, RADeg, decDeg, clipSizeDeg,
     else:
         
         if REPORT_ERRORS==True:
-            print """ERROR: astImages.clipRotatedImageSectionWCS() : 
-            RADeg, decDeg are not within imageData."""
+            print("""ERROR: astImages.clipRotatedImageSectionWCS() : 
+            RADeg, decDeg are not within imageData.""")
         
         return None
 
@@ -400,7 +399,7 @@ def clipUsingRADecCoords(imageData, imageWCS, RAMin, RAMax, decMin, decMax, retu
             
             if REPORT_ERRORS == True:
                 
-                print "WARNING: astImages.clipUsingRADecCoords() : no CRPIX1, CRPIX2 keywords found - not updating clipped image WCS."
+                print("WARNING: astImages.clipUsingRADecCoords() : no CRPIX1, CRPIX2 keywords found - not updating clipped image WCS.")
                 
                 clippedData=imageData[Y[0]:Y[1],X[0]:X[1]]
                 clippedWCS=imageWCS.copy()
@@ -452,7 +451,7 @@ def scaleImage(imageData, imageWCS, scaleFactor):
             CD22=imageWCS.header['CDELT2']
         except KeyError:
             if REPORT_ERRORS == True:
-                print "WARNING: astImages.rescaleImage() : no CDij or CDELT keywords found - not updating WCS."
+                print("WARNING: astImages.rescaleImage() : no CDij or CDELT keywords found - not updating WCS.")
             scaledWCS=imageWCS.copy()
             return {'data': scaledData, 'wcs': scaledWCS}
 
@@ -774,7 +773,7 @@ def generateContourOverlay(backgroundImageData, backgroundImageWCS, contourImage
     # For compromise between speed and accuracy, scale a copy of the background
     # image down to a scale that is one pixel = 1/5 of a pixel in the contour image
     # But only do this if it has CDij keywords as we know how to scale those
-    if backgroundImageWCS.header.has_key("CD1_1") == True:
+    if ("CD1_1" in backgroundImageWCS.header) == True:
         xScaleFactor=backgroundImageWCS.getXPixelSizeDeg()/(contourImageWCS.getXPixelSizeDeg()/5.0)
         yScaleFactor=backgroundImageWCS.getYPixelSizeDeg()/(contourImageWCS.getYPixelSizeDeg()/5.0)
         scaledBackground=scaleImage(backgroundImageData, backgroundImageWCS, (xScaleFactor, yScaleFactor))
@@ -822,7 +821,7 @@ def generateContourOverlay(backgroundImageData, backgroundImageWCS, contourImage
         else:
             xMax=float(contourLevels[2])     
         if xMin <= 0.0:
-            raise Exception, "minimum contour level set to <= 0 and log scaling chosen."
+            raise Exception("minimum contour level set to <= 0 and log scaling chosen.")
         xLogMin=math.log10(xMin)
         xLogMax=math.log10(xMax)
         nLevels=contourLevels[3]
@@ -878,7 +877,7 @@ def saveBitmap(outputFileName, imageData, cutLevels, size, colorMapName):
     try:
         colorMap=pylab.cm.get_cmap(colorMapName)
     except AssertionError:
-        raise Exception, colorMapName+" is not a defined matplotlib colormap."
+        raise Exception(colorMapName+" is not a defined matplotlib colormap.")
     
     if cutLevels[0]=="histEq":
         pylab.imshow(cut['image'],  interpolation="bilinear", origin='lower', cmap=colorMap)
@@ -895,7 +894,7 @@ def saveBitmap(outputFileName, imageData, cutLevels, size, colorMapName):
     try:
         from PIL import Image
     except:
-        raise Exception, "astImages.saveBitmap requires the Python Imaging Library to be installed."
+        raise Exception("astImages.saveBitmap requires the Python Imaging Library to be installed.")
     im=Image.open("out_astImages.png")
     im.thumbnail((int(size),int(size)))
     im.save(outputFileName)
@@ -962,7 +961,7 @@ def saveContourOverlayBitmap(outputFileName, backgroundImageData, backgroundImag
     try:
         colorMap=pylab.cm.get_cmap(colorMapName)
     except AssertionError:
-        raise Exception, colorMapName+" is not a defined matplotlib colormap."
+        raise Exception(colorMapName+" is not a defined matplotlib colormap.")
     
     if cutLevels[0]=="histEq":
         pylab.imshow(cut['image'],  interpolation="bilinear", origin='lower', cmap=colorMap)
@@ -986,7 +985,7 @@ def saveContourOverlayBitmap(outputFileName, backgroundImageData, backgroundImag
     try:
         from PIL import Image
     except:
-        raise Exception, "astImages.saveContourOverlayBitmap requires the Python Imaging Library to be installed"
+        raise Exception("astImages.saveContourOverlayBitmap requires the Python Imaging Library to be installed")
     
     im=Image.open("out_astImages.png")
     im.thumbnail((int(size),int(size)))
@@ -1054,7 +1053,7 @@ def histEq(inputArray, numBins):
         binNumber=int(math.ceil((sortedDataIntensities[i]-minIntensity)/binWidth))
         addArray=numpy.zeros(numBins)
         onesArray=numpy.ones(numBins-binNumber)
-        onesRange=range(binNumber, numBins)
+        onesRange=list(range(binNumber, numBins))
         numpy.put(addArray, onesRange, onesArray)
         dataCumHist=dataCumHist+addArray
                 
