@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 """module for performing calculations on Spectral Energy Distributions (SEDs)
 
-(c) 2007-2011 Matt Hilton 
+(c) 2007-2013 Matt Hilton 
 
 U{http://astlib.sourceforge.net}
 
@@ -29,7 +28,7 @@ try:
     from scipy import ndimage
     from scipy import optimize
 except:
-    print "WARNING: astSED: failed to import scipy modules - some functions will not work."
+    print("WARNING: astSED: failed to import scipy modules - some functions will not work.")
 import astLib
 from astLib import astCalc
 import os
@@ -38,7 +37,7 @@ try:
     from matplotlib import pylab
     matplotlib.interactive(False)
 except:
-    print "WARNING: astSED: failed to import matplotlib - some functions will not work."
+    print("WARNING: astSED: failed to import matplotlib - some functions will not work.")
 import glob
 
 #------------------------------------------------------------------------------------------------------------
@@ -58,7 +57,7 @@ class Passband:
     """
     def __init__(self, fileName, normalise = True, inputUnits = 'angstroms'):
         
-        inFile=file(fileName, "rb")
+        inFile=open(fileName, "r")
         lines=inFile.readlines()
         
         wavelength=[]
@@ -86,7 +85,7 @@ class Passband:
             self.wavelength=3e8/(self.wavelength*1e9)
             self.wavelength=self.wavelength*1e10
         else:
-            raise Exception, "didn't understand passband input units"
+            raise Exception("didn't understand passband input units")
     
         # Sort into ascending order of wavelength otherwise normalisation will be wrong
         merged=numpy.array([self.wavelength, self.transmission]).transpose()
@@ -162,8 +161,8 @@ class Passband:
         
         """
         
-        a=numpy.trapz(self.transmission*self.wavelength)
-        b=numpy.trapz(self.transmission/self.wavelength)
+        a=numpy.trapz(self.transmission*self.wavelength, self.wavelength)
+        b=numpy.trapz(self.transmission/self.wavelength, self.wavelength)
         effWavelength=numpy.sqrt(a/b)
         
         return effWavelength
@@ -259,7 +258,7 @@ class SED:
         
         """
         
-        inFile=file(fileName, "rb")
+        inFile=open(fileName, "r")
         lines=inFile.readlines()
         inFile.close()
         wavelength=[]
@@ -289,7 +288,7 @@ class SED:
         
         """
         
-        outFile=file(fileName, "wb")
+        outFile=open(fileName, "w")
         for l, f in zip(self.wavelength, self.flux):
             outFile.write(str(l)+" "+str(f)+"\n")
         outFile.close()
@@ -600,7 +599,7 @@ class SED:
                 mask=numpy.greater(self.z0wavelength, 22000.0)
                 kPrime[mask]=slope*self.z0wavelength[mask]+intercept
             except:
-                raise Exception, "This SED has a wavelength range that doesn't cover ~1200-22000 Angstroms"
+                raise Exception("This SED has a wavelength range that doesn't cover ~1200-22000 Angstroms")
                             
             # Never let go negative
             kPrime[numpy.less_equal(kPrime, 0.0)]=1e-6
@@ -623,7 +622,7 @@ class VegaSED(SED):
         
         VEGA_SED_PATH=astLib.__path__[0]+os.path.sep+"data"+os.path.sep+"bohlin2006_Vega.sed" # from HST CALSPEC
 
-        inFile=file(VEGA_SED_PATH, "rb")
+        inFile=open(VEGA_SED_PATH, "r")
         lines=inFile.readlines()
         
         wavelength=[]
@@ -664,7 +663,7 @@ class StellarPopulation:
     """
     def __init__(self, fileName, ageColumn = 0, wavelengthColumn = 1, fluxColumn = 2):
        
-        inFile=file(fileName, "rb")
+        inFile=open(fileName, "r")
         lines=inFile.readlines()
         inFile.close()
 
@@ -873,7 +872,7 @@ class M05Model(StellarPopulation):
    
         self.modelFamily="M05"
 
-        inFile=file(fileName, "rb")
+        inFile=open(fileName, "r")
         lines=inFile.readlines()
         inFile.close()
         
@@ -888,7 +887,7 @@ class M05Model(StellarPopulation):
             wavelengthColumn=2
             fluxColumn=3
         else:
-            raise Exception, "fileType must be 'ssp' or 'csp'"
+            raise Exception("fileType must be 'ssp' or 'csp'")
         
         # Extract a list of model ages and valid wavelengths from the file
         self.ages=[]
@@ -940,7 +939,7 @@ class BC03Model(StellarPopulation):
         self.modelFamily="BC03"
         self.fileName=fileName
 
-        inFile=file(fileName, "rb")
+        inFile=open(fileName, "r")
         lines=inFile.readlines()
         inFile.close()
         
@@ -1021,7 +1020,7 @@ class P09Model(StellarPopulation):
             for e in extensionAgeMap.keys():
                 if extensionAgeMap[e] == self.ages[i]:
                     inFileName=glob.glob(fileName+os.path.sep+"*."+e)[0]
-                    inFile=file(inFileName, "rb")
+                    inFile=open(inFileName, "r")
                     lines=inFile.readlines()
                     inFile.close()
                     wavelength=[]
@@ -1082,7 +1081,7 @@ def makeModelSEDDictList(modelList, z, passbandsList, labelsList = [], EBMinusVL
                 try:
                     s.extinctionCalzetti(EBMinusV)
                 except:
-                    raise Exception, "Model %s has a wavelength range that doesn't cover ~1200-22000 Angstroms" % (modelList[m].fileName)
+                    raise Exception("Model %s has a wavelength range that doesn't cover ~1200-22000 Angstroms" % (modelList[m].fileName))
                 modelSEDDict=s.getSEDDict(passbandsList)
                 modelSEDDict['labels']=labelsList
                 modelSEDDict['E(B-V)']=EBMinusV
