@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 """module for performing statistical calculations.
 
-(c) 2007-2011 Matt Hilton 
+(c) 2007-2012 Matt Hilton 
+
+(c) 2013 Matt Hilton & Steven Boada
 
 U{http://astlib.sourceforge.net}
 
@@ -130,7 +132,7 @@ def weightedStdev(dataList):
         stdev=math.sqrt(nFactor*(sum/wSum))
     else:
         if REPORT_ERRORS==True:
-            print """ERROR: astStats.weightedStdev() : dataList contains < 2 items."""
+            print("""ERROR: astStats.weightedStdev() : dataList contains < 2 items.""")
         stdev=None
     return stdev
         
@@ -253,7 +255,7 @@ def biweightLocation(dataList, tuningConstant):
         
     else:
         if REPORT_ERRORS==True:
-            print """ERROR: astStats: biweightLocation() : MAD() returned 0."""
+            print("""ERROR: astStats: biweightLocation() : MAD() returned 0.""")
         return None
     
     return CBI
@@ -287,7 +289,7 @@ def biweightScale(dataList, tuningConstant):
             uValues.append((item-listMedian)/(C*listMAD))
         except ZeroDivisionError:
             if REPORT_ERRORS==True:
-                print """ERROR: astStats.biweightScale() : divide by zero error."""
+                print("""ERROR: astStats.biweightScale() : divide by zero error.""")
             return None
         
     top=0		# numerator equation (9) Beers et al
@@ -349,8 +351,8 @@ def biweightClipped(dataList, tuningConstant, sigmaCut):
         if cbi==None or sbi==None:
             
             if REPORT_ERRORS==True:
-                print """ERROR: astStats : biweightClipped() :
-                divide by zero error."""
+                print("""ERROR: astStats : biweightClipped() :
+                divide by zero error.""")
             
             return None
             
@@ -442,11 +444,17 @@ def OLSFit(dataList):
             
         sigma=math.sqrt((1.0/(n-2))*sumRes)
         
-        mSigma=(sigma*math.sqrt(n))/math.sqrt((n*sumXX)-(sumX*sumX))
-        cSigma=(sigma*math.sqrt(sumXX))/math.sqrt((n*sumXX)-(sumX*sumX))
+        try:
+            mSigma=(sigma*math.sqrt(n))/math.sqrt((n*sumXX)-(sumX*sumX))
+        except:
+            mSigma=numpy.nan
+        try:
+            cSigma=(sigma*math.sqrt(sumXX))/math.sqrt((n*sumXX)-(sumX*sumX))
+        except:
+            cSigma=numpy.nan
     else:
         if REPORT_ERRORS==True:
-            print """ERROR: astStats.OLSFit() : dataList contains < 3 items."""
+            print("""ERROR: astStats.OLSFit() : dataList contains < 3 items.""")
             
         return None
         
@@ -514,8 +522,8 @@ def clippedWeightedLSFit(dataList, sigmaCut):
         if fitResults['slope'] == None:
             
             if REPORT_ERRORS==True:
-                print """ERROR: astStats : clippedWeightedLSFit() :
-                divide by zero error."""
+                print("""ERROR: astStats : clippedWeightedLSFit() :
+                divide by zero error.""")
             
             return None
             
@@ -576,7 +584,7 @@ def weightedLSFit(dataList, weightType):
                 /((sumW*sumWXX)-(sumWX*sumWX))
             except ZeroDivisionError:
                 if REPORT_ERRORS == True:
-                    print "ERROR: astStats.weightedLSFit() : divide by zero error."
+                    print("ERROR: astStats.weightedLSFit() : divide by zero error.")
                 return None
         
             try:
@@ -584,7 +592,7 @@ def weightedLSFit(dataList, weightType):
                 /((sumW*sumWXX)-(sumWX*sumWX))
             except ZeroDivisionError:
                 if REPORT_ERRORS == True:
-                    print "ERROR: astStats.weightedLSFit() : divide by zero error."
+                    print("ERROR: astStats.weightedLSFit() : divide by zero error.")
                 return None
             
             sumRes=0
@@ -608,14 +616,14 @@ def weightedLSFit(dataList, weightType):
             else:
                 
                 if REPORT_ERRORS==True:
-                    print """ERROR: astStats.weightedLSFit()
-                    : divide by zero error."""
+                    print("""ERROR: astStats.weightedLSFit()
+                    : divide by zero error.""")
                 return None
                 
         else:
             if REPORT_ERRORS==True:
-                print """ERROR: astStats.weightedLSFit() :
-                dataList contains < 5 items."""
+                print("""ERROR: astStats.weightedLSFit() :
+                dataList contains < 5 items.""")
             return None
             
     elif weightType == "errors":
